Authors:

* Peter Amstutz <peter.amstutz@curoverse.com>, Arvados Project, Curoverse
* Nebojša Tijanić <nebojsa.tijanic@sbgenomics.com>, Seven Bridges Genomics

Contributers:

* Brad Chapman <bchapman@hsph.harvard.edu>, Harvard Chan School of Public Health
* John Chilton <jmchilton@gmail.com>, Galaxy Project, Pennsylvania State University
* Michael R. Crusoe <crusoe@ucdavis.edu>, University of California, Davis
* Andrey Kartashov <Andrey.Kartashov@cchmc.org>, Cincinnati Children's Hospital
* Dan Leehr <dan.leehr@duke.edu>, Duke University
* Hervé Ménager <herve.menager@gmail.com>, Institut Pasteur
* Stian Soiland-Reyes [soiland-reyes@cs.manchester.ac.uk](mailto:soiland-reyes@cs.manchester.ac.uk), University of Manchester
* Luka Stojanovic <luka.stojanovic@sbgenomics.com>, Seven Bridges Genomics
